#!/bin/sh
export PATH=/usr/local/sbin:/usr/sbin:/sbin:/usr/local/bin:/usr/bin:/bin
#
# If ACUConfig terminates with
#
# terminate called after throwing an instance of 'std::length_error'
#  what():  basic_string::_S_create
# Aborted
#
# you need to use an older libstdc++, the one of gcc4.4.6 works.
# Uncomment the following line after adjusting it.
#
LIBSTDC=/usr/lib64/gcc/x86_64-pc-linux-gnu/4.4.6/libstdc++.so.6.0.13
#
# Either use the binary ACUConfig as being shipped for Linux AMT
# or use the one you did compile
#
ACUCONFIG=../ACUConfig.bin/ACUConfig
#ACUCONFIG=../ACUConfig.src/ACUConfig
#
# Notes:
#
# ACUConfig requires the file en_US.UTF-8_ACUMessages.cat in the same
# directory ACUConfig resides in. Expect broken output if you do
# not comply.
#
# ACUConfig chokes on tun and ppp interfaces. It segfaults.
# Shutdown all such interfaces before using ACUConfig.
# The "error" displayed by ACUConfig in this case:
#
# ***** Start ClientControlConfiguration ******
#
# Segmentation fault
#
# ACUConfig requires the directory $HOME/.config to exist and
# to be writable. Otherwise it fails with:
#
# Exit with code 8 - Invalid command parameter.
# Details: configured (DecryptionPassword)
#
# If ACUConfig unexpectedly terminates with
#
# Intel(R) AMT Profile Configuration failed. Failed to complete remote configuration of this Intel(R) AMT device. . %1 is not implemented in %2.  - 0xc0002341. ().
#
# access AMT through the web interface (port 16992), clear the domain name and
# switch off the "Shared FQDN" checkmark.
#
encrypt()
{
str=`echo -n "$2" | openssl dgst -sha256 -hex | cut -d' ' -f2`
v1=`echo $str | cut -b1-32`
v2=`echo $str | cut -b33-64`
openssl aes-128-cbc -e -in "$1" -K $v1 -iv $v2 -nosalt
}

if [ `basename $0` = amtstatus.sh ]
then
	true
elif [ "$1" = "" ]
then
	echo "*** WARNING ***"
	echo "No password given, using default of usb key provisioning."
	pass='Pa$$w0rd'
else
	pass="$1"
fi

if [ `ifconfig | grep -c POINTOPOINT` != 0 ]
then
	echo "tun or ppp interface(s) found. Aborting."
	exit 1
fi

if [ "$HOME" = "" ]
then
	echo '$HOME not set. Aborting.'
fi

if [ ! -d $HOME/.config ]
then
	mkdir $HOME/.config || exit 1
fi

test -w $HOME/.config
if [ $? != 0 ]
then
	echo "$HOME/.config is not writable. Aborting."
fi

case `basename $0` in
amtconfig.sh)
	encrypt config.xml.in 'P@ssw0rd' > config.xml
	encrypt network.xml.in 'P@ssw0rd' > network.xml

	[ "$LIBSTDC" != "" ] && export LD_PRELOAD=$LIBSTDC
	$ACUCONFIG -Verbose -Output Console ConfigAMT config.xml \
		-DecryptionPassword 'P@ssw0rd' \
		-NetworkSettingsFile network.xml \
		-AdminPassword "$pass"
	exit $?
	;;
amtclient.sh)
	[ "$LIBSTDC" != "" ] && export LD_PRELOAD=$LIBSTDC
	$ACUCONFIG -Verbose -Output Console ConfigAMT profile.xml \
		-AdminPassword "$pass"
	exit $?
	;;
amtunconfig.sh)
	[ "$LIBSTDC" != "" ] && export LD_PRELOAD=$LIBSTDC
	$ACUCONFIG -Verbose -Output Console UnConfigure -Full \
		-AdminPassword "$pass"
	exit $?
	;;
amtstatus.sh)
	[ "$LIBSTDC" != "" ] && export LD_PRELOAD=$LIBSTDC
	$ACUCONFIG -Verbose -Output Console Status
	exit $?
esac
